Widgets
=======

Standard UI widgets for building interfaces.

Button
------

.. automodule:: mytk.button
   :members:
   :show-inheritance:

Checkbox
--------

.. automodule:: mytk.checkbox
   :members:
   :show-inheritance:

RadioButton
-----------

.. automodule:: mytk.radiobutton
   :members:
   :show-inheritance:

Labels
------

.. automodule:: mytk.labels
   :members:
   :show-inheritance:

Entries
-------

.. automodule:: mytk.entries
   :members:
   :show-inheritance:

Slider
------

.. automodule:: mytk.controls
   :members:
   :show-inheritance:

PopupMenu
---------

.. automodule:: mytk.popupmenu
   :members:
   :show-inheritance:
